@@ -2,7 +2,7 @@
 RESTful resource variant selection using the HTTP Accept header.
 """
 
-__version__   = '0.5.1'
+__version__   = '0.5.3'
 __author__    = 'Martin Blech <martinblech@gmail.com>'
 __license__   = 'MIT'
 
@@ -330,11 +330,7 @@ try:
             del flask.request.environ[key]
 
         def _make_response(self, content, headers, status):
-            response = flask.make_response(content)
-            response.status = status
-            for k, v in headers:
-                response.headers[k] = v
-            return response
+            return flask.make_response(content, status, headers)
 
 except ImportError:
     pass
